@@ -1,6 +1,6 @@
 /* Certificate Management library
  * 
- * Copyright (C) 2005 Nokia. All rights reserved.
+ * Copyright (C) 2005 - 2008 Nokia Corporation. All rights reserved.
  * Author: Ed Bartosh <Eduard.Bartosh@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -229,7 +229,7 @@ typedef guint64 cst_t_mcount;
 
     @param readonly  If storage will be readonly (NOT USED)
     @param password  Password for storage or NULL if password is empty (NOT USED)
-    @return NULL if error, see CST_lasError()
+    @return NULL if error, see CST_last_error()
     
     Possible error:  CST_ERROR_NOT_FOUND, CST_ERROR_DBSTRUCTURE_CORRUPT, 
     CST_ERROR_IO, CST_ERROR_NOSPC, CST_ERROR_LOCK
@@ -243,7 +243,7 @@ typedef guint64 cst_t_mcount;
    @param filename  Filename of local storage
    @param readonly  If storage will be readonly (NOT USED)
    @param password  Password for storage or NULL if password is empty (NOT USED)
-   @return NULL if error, see CST_lasError()
+   @return NULL if error, see CST_last_error()
    
    Possible error:  CST_ERROR_NOT_FOUND, CST_ERROR_DBSTRUCTURE_CORRUPT
    CST_ERROR_IO, CST_ERROR_NOSPC, CST_ERROR_LOCK
@@ -1218,13 +1218,13 @@ typedef guint64 cst_t_mcount;
 
 /**
    @ingroup Cert
-   Get valid to
+   Get valid from
 */
     extern time_t CST_get_valid_from(X509 * cert);
 
 /**
    @ingroup Cert
-   Get valid from
+   Get valid to
 */
     extern time_t CST_get_valid_to(X509 * cert);
 
@@ -1528,25 +1528,25 @@ typedef guint64 cst_t_mcount;
 
 /**
     @ingroup Cert
-    Check certificate validity
+    Check if certificate is trusted
 */
     extern int CST_is_valid(CST * st, X509 * cert);
 
 /**
     @ingroup Cert
-    Check certificate validity. Read certificate from file (PEM format).
+    Check if certificate is trusted. Read certificate from file (PEM format).
 */
     extern int CST_is_valid_f(CST * st, FILE * file, GError **error);
     
 /**
     @ingroup Cert
-    Check certificate validity. Read certificate from file (DER format).
+    Check if certificate is trusted. Read certificate from file (DER format).
 */    
     extern int CST_is_valid_f_DER(CST * st, FILE * file, GError **error);
     
 /**
     @ingroup Cert
-    Check certificate validity
+    Check if certificate is trusted for given purpose
 */   
     extern int CST_is_valid_for(CST * st, 
             X509 * cert, const cst_t_cert_purpose purpose);
@@ -1595,9 +1595,9 @@ typedef guint64 cst_t_mcount;
 
 /**
     @ingroup Cert
-    @brief Get state of certificate 
+    @brief Get overall state of certificate 
     
-    see: CST_STATE_REVOKED, CST_STATE_EXPIRED, ...
+    see: CST_STATE_VALID, CST_STATE_NOTVALID, CST_STATE_REVOKED, CST_STATE_EXPIRED ...
 */
     extern int CST_get_state(CST * st, X509 * cert);
 
@@ -1633,7 +1633,7 @@ typedef guint64 cst_t_mcount;
 
     X509 * cert = ... // Some cert received from server
 
-    if (CST_is_valid(storage, cert))
+    if (CST_get_state(storage, cert) == CST_STATE_VALID)
     {
         printf("Certificate is valid");
     }
