@@ -29,7 +29,9 @@
 #include <string.h>
 #include "cst_t.h"
 #include <gconf/gconf-client.h>
+#include <gconf/gconf-engine.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -279,14 +281,29 @@ CST *CST_open(const int readonly, unsigned char *password)
 {
     TRACE("*");
     
-    GConfClient * client = gconf_client_get_default();
     gchar * filename = NULL;
     gchar * fn = NULL;
-    if (client)
+    gchar * gconf_interface = getenv("CERTMAN_USE_GCONF_ENGINE");
+
+    if (gconf_interface != NULL) 
     {
-        filename = gconf_client_get_string(client, DEFAULT_GCONF_KEY_FILENAME, NULL);
-        fn = filename;
-        g_object_unref(G_OBJECT(client));
+        GConfEngine * engine = gconf_engine_get_default(); 
+        if (engine != NULL) 
+	{
+	    filename = gconf_engine_get_string(engine, DEFAULT_GCONF_KEY_FILENAME, NULL);
+	    fn = filename;
+	    gconf_engine_unref(engine); 
+        }
+    } 
+    else 
+    {
+        GConfClient * client = gconf_client_get_default();
+        if (client) 
+	{
+	    filename = gconf_client_get_string(client, DEFAULT_GCONF_KEY_FILENAME, NULL);
+	    fn = filename;
+	    g_object_unref(G_OBJECT(client));
+        }
     }
 
     if (!fn)
